#[non_exhaustive]pub enum MissingCapability {
StructuredOutput {
required: Vec<StructuredOutputCapability>,
declared: StructuredOutputCapability,
},
ToolCalling,
Streaming,
Vision,
Documents,
ContextWindow {
required: u64,
declared: Option<u64>,
},
}Expand description
One capability a provider lacks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StructuredOutput
The declared structured-output transport is not in the accepted set.
Fields

required: Vec<StructuredOutputCapability>Transports that would have been accepted.

declared: StructuredOutputCapabilityWhat the profile declares.
ToolCalling
Tools are needed but the model declares none.
Streaming
Streaming is needed but not declared.
Vision
Vision is needed but not declared.
Documents
A document part is present but document input is not declared.
ContextWindow
The declared context window is unknown or too small.