pub struct Message {
pub role: Role,
pub content: Vec<ContentPart>,
}Expand description
One message in the conversation sent to the model.
Fields
role: RoleWho is speaking.
content: Vec<ContentPart>What they said, in order.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn new(role: Role, content: Vec<ContentPart>) -> Self
pub fn new(role: Role, content: Vec<ContentPart>) -> Self
A message with explicit parts.
Sourcepub fn tool_result(result: ToolResult) -> Self
pub fn tool_result(result: ToolResult) -> Self
A tool message carrying one result.
Sourcepub fn with_part(self, part: ContentPart) -> Self
pub fn with_part(self, part: ContentPart) -> Self
Appends a part.
Sourcepub fn has_document(&self) -> bool
pub fn has_document(&self) -> bool
Returns true when the message carries a document part.