pub struct ProviderHealth {
pub consecutive_failures: u32,
pub degraded_until: Option<DateTime<Utc>>,
pub successes: u64,
pub failures: u64,
}Expand description
A snapshot of one profile’s recent record.
Fields
consecutive_failures: u32Failures since the last success.
degraded_until: Option<DateTime<Utc>>When the profile becomes eligible again, when it is degraded.
successes: u64Successful calls recorded.
failures: u64Failed calls recorded.
Implementations
Sourceimpl ProviderHealth
impl ProviderHealth
Sourcepub fn is_healthy_at(&self, now: DateTime<Utc>) -> bool
pub fn is_healthy_at(&self, now: DateTime<Utc>) -> bool
Returns true when the profile is not in a cooldown window at now.